@@ -4,7 +4,6 @@ All configurations for pyscrapers
 import os
 import logging
 
-import browser_cookie3
 from pytconf import Config, ParamCreator
 
 
@@ -24,8 +23,7 @@ class ConfigLogging(Config):
             logging.getLevelName(logging.CRITICAL),
         ],
         help_string="What log level to use?",
-        default=logging.getLevelName(logging.ERROR),
-
+        default=logging.getLevelName(logging.INFO),
     )
 
 
@@ -65,18 +63,10 @@ class ConfigCookiesSource(Config):
     browser = ParamCreator.create_choice(
         choice_list=["none", "firefox", "chrome"],
         help_string="Which browser to take cookies from?",
-        default="firefox",
+        default="chrome",
     )
 
 
-def get_cookies():
-    if ConfigCookiesSource.browser == "firefox":
-        return browser_cookie3.firefox()
-    if ConfigCookiesSource.browser == "chrome":
-        return browser_cookie3.chrome()
-    raise ValueError(f"unsupported browser [{ConfigCookiesSource.browser}")
-
-
 class ConfigSiteId(Config):
     """
     Parameters for downloading workers
@@ -95,6 +85,15 @@ class ConfigSiteId(Config):
     )
 
 
+class ConfigUser(Config):
+    """
+    Parameters for a user
+    """
+    user = ParamCreator.create_str(
+        help_string="Which user id to user?",
+    )
+
+
 class ConfigPornhubSearch(Config):
     """
     Parameters for search
@@ -177,3 +176,7 @@ class ConfigRequests(Config):
         help_string="Do you want to debug the requests module?",
         default=False,
     )
+    progress = ParamCreator.create_bool(
+        help_string="Do you want to display progress?",
+        default=False,
+    )
