@@ -1,10 +1,11 @@
 import logging
 import os
-import shutil
 import urllib.parse
-from typing import Union, List
+from collections import Counter
+from typing import List
 
 from pyscrapers.configs import ConfigDownload
+from pyscrapers.core.ext_requests import download
 
 
 class UrlSet:
@@ -17,7 +18,7 @@ class UrlSet:
         self.urls_list = []
         self.appended_twice = 0
         self.counter_jpg = 0
-        self.counter_mp4 = 0
+        self.counter_video = 0
 
     def append(self, url: str) -> None:
         """
@@ -45,18 +46,16 @@ class UrlSet:
         for url in self.urls_list:
             print(url)
 
-    def suggest_filename(self, suffix: str) -> Union[str, None]:
+    def suggest_filename(self, suffix: str) -> str:
         if suffix == ".jpg":
-            filename = f"image{self.counter_jpg:0:04}.jpg"
+            filename = f"image{self.counter_jpg:04d}.jpg"
             self.counter_jpg += 1
             return filename
-        if suffix == ".mp4":
-            filename = f"video{self.counter_mp4:0:04}.mp4"
-            self.counter_mp4 += 1
+        if suffix in (".mp4", ".webp"):
+            filename = f"video{self.counter_video:04d}{suffix}"
+            self.counter_video += 1
             return filename
-        logger = logging.getLogger(__name__)
-        logger.error(f"do not know how to handle suffix [{suffix}]...")
-        return None
+        raise ValueError(f"dont know how to handle suffix [{suffix}]")
 
     def get_filename(self, suffix: str) -> str:
         filename = self.suggest_filename(suffix)
@@ -70,21 +69,26 @@ class UrlSet:
         :param session:
         :return:
         """
+        skipped = 0
+        downloads_per_suffix = Counter()
         logger = logging.getLogger(__name__)
-        logger.info('got [%d] urls', len(self.urls_list))
+        logger.info(f"got [{len(self.urls_list)}] urls")
         if ConfigDownload.download:
             for url in self.urls_list:
                 parse_result = urllib.parse.urlparse(url)
                 path = parse_result.path
-                logger.info('downloading [%s]...', url)
-                response = session.get(url, stream=True)
-                response.raise_for_status()
-
-                filename = self.get_filename(os.path.splitext(path)[1])
+                suffix = os.path.splitext(path)[1]
+                filename = self.get_filename(suffix)
                 if filename is None:
+                    skipped += 1
+                    logger.info(f"skipping [{path}]...")
                     continue
 
-                with open(filename, 'wb') as file_handle:
-                    response.raw.decode_content = True
-                    shutil.copyfileobj(response.raw, file_handle)
-                logger.info('written [%s]...', filename)
+                logger.info(f"downloading [{path}] to [{filename}]...")
+                response = session.get(url, stream=True)
+                response.raise_for_status()
+                downloads_per_suffix[suffix] += 1
+                download(response, filename)
+                logger.info(f"written [{filename}]...")
+        logger.info(f"skipped [{skipped}]...")
+        logger.info(downloads_per_suffix)
