@@ -7,16 +7,13 @@ import logging
 import os
 
 import lxml.html
+from pyscrapers.core.ext_lxml import setup_prefix
+from pyscrapers.core.ext_requests import ExtSession
 
-from pyscrapers.core.utils import download_url, download_video_if_wider
-
-# this means that we can use regular expression functions like 'match'
-# by specifying 're:match' in our xpath expressions
-ns = lxml.etree.FunctionNamespace("http://exslt.org/regular-expressions")
-ns.prefix = 're'
+setup_prefix()
 
 
-def get_number_of_pages(courses: bool, session) -> int:
+def get_number_of_pages(courses: bool, session: ExtSession) -> int:
     """
     Get the number of pages for all courses or pages
     :param courses:
@@ -28,7 +25,7 @@ def get_number_of_pages(courses: bool, session) -> int:
     else:
         url = "https://www.drumeo.com/laravel/public/members-area/json/lesson-group/library?page=1"
     result = session.get(url)
-    assert result.status_code == 200
+    result.raise_for_status()
     content = result.content.decode()
     obj = json.loads(content)
     d_page_count = obj["pageCount"]
@@ -81,17 +78,17 @@ class Course:
 
 def get_url(courses: bool, page: int) -> str:
     if courses:
-        url = "https://www.drumeo.com/laravel/public/members-area/json/lesson-group/courses?page={}".format(page)
+        url = f"https://www.drumeo.com/laravel/public/members-area/json/lesson-group/courses?page={page}"
     else:
-        url = "https://www.drumeo.com/laravel/public/members-area/json/lesson-group/library?page={}".format(page)
+        url = f"https://www.drumeo.com/laravel/public/members-area/json/lesson-group/library?page={page}"
     return url
 
 
 def get_members_url(courses: bool, number: int) -> str:
     if courses:
-        url = "https://www.drumeo.com/members/lessons/courses/{}".format(number)
+        url = f"https://www.drumeo.com/members/lessons/courses/{number}"
     else:
-        url = "https://www.drumeo.com/members/lessons/library/{}".format(number)
+        url = f"https://www.drumeo.com/members/lessons/library/{number}"
     return url
 
 
@@ -114,11 +111,11 @@ def get_courses(pages, courses: bool, session):
     collected_courses = []
     for page in range(1, pages + 1):
         result = session.get(get_url(courses, page))
-        assert result.status_code == 200
+        result.raise_for_status()
         for lesson_list in json.loads(result.content.decode())["lessonsHtml"]:
             course = Course()
             root = lxml.html.fromstring(lesson_list)
-            links = root.xpath('//a[re:match(@href,"{}")]'.format(get_link_re(courses)))
+            links = root.xpath(f"//a[re:match(@href,\"{get_link_re(courses)}\")]")
             assert len(links) == 2, len(links)
             course.number = links[0].get('href').split("/")[-1]
             titles = root.xpath('//h2[@class="card-title"]')
@@ -143,21 +140,21 @@ def get_course_details(course: Course, courses: bool, session):
     :return:
     """
     result = session.get(get_members_url(courses, course.number))
-    assert result.status_code == 200
+    result.raise_for_status()
     content = result.content.decode()
     root = lxml.html.fromstring(content)
     if courses:
         class_text = "course-lesson"
     else:
         class_text = "event-toggle download-lesson"
-    lessons = root.xpath('//a[@class="{}"]'.format(class_text))
+    lessons = root.xpath(f"//a[@class=\"{class_text}\"]")
     for lesson in lessons:
         lesson_num = lesson.get('href').split('/')[-1]
         course.add_lesson(lesson_num)
     resources = root.xpath('//a[re:match(text(), "All Course Resources")]')
     if len(resources) == 1:
         resource = resources[0].get('href')
-        course.resources = "http:"+resource
+        course.resources = "http:" + resource
     if not courses:
         get_videos(root, course, session)
 
@@ -169,11 +166,11 @@ def get_course_urls(course, courses: bool, session):
     logger.info("doing course [%s]", course)
     for lesson in course.lessons:
         if courses:
-            url = "https://www.drumeo.com/members/lessons/courses/{}".format(lesson)
+            url = f"https://www.drumeo.com/members/lessons/courses/{lesson}"
         else:
-            url = "https://www.drumeo.com/members/lessons/library/{}".format(lesson)
+            url = f"https://www.drumeo.com/members/lessons/library/{lesson}"
         result = session.get(url)
-        assert result.status_code == 200
+        result.raise_for_status()
         content = result.content.decode()
         print(content)
         root = lxml.html.fromstring(content)
@@ -194,7 +191,7 @@ def get_videos(root, course, session):
         video_url = video.get('data-video-load-url')
         logger.info("url for video info is [%s]", video_url)
         result = session.get(video_url)
-        assert result.status_code == 200
+        result.raise_for_status()
         content = result.content.decode()
         data = json.loads(content)
         if 'error' in data:
@@ -224,11 +221,11 @@ def download_course(course, session):
     details = os.path.join(folder_name, "details.txt")
     if not os.path.isfile(details):
         with open(details, "wt") as file_handle:
-            print("course_number: {}".format(course.number), file=file_handle)
-            print("course_name: {}".format(course.name), file=file_handle)
-            print("course_difficulty: {}".format(course.diff), file=file_handle)
-            print("instructor: {}".format(course.instructor), file=file_handle)
+            print(f"course_number: {course.number}", file=file_handle)
+            print(f"course_name: {course.name}", file=file_handle)
+            print(f"course_difficulty: {course.diff}", file=file_handle)
+            print(f"instructor: {course.instructor}", file=file_handle)
     if course.resources is not None:
-        download_url(course.resources, os.path.join(folder_name, "resources.zip"), session)
+        session.download_url(course.resources, os.path.join(folder_name, "resources.zip"), session)
     for i, (video, quality) in enumerate(course.videos):
-        download_video_if_wider(session, video, os.path.join(folder_name, "{}.mp4".format(i)), width=int(quality))
+        session.download_video_if_wider(session, video, os.path.join(folder_name, f"{i}.mp4"), width=int(quality))
