@@ -10,9 +10,7 @@ import logging
 import time
 
 import pyeventroute.route
-from lxml import etree
 
-import pyscrapers.core.utils
 from pyscrapers.core.url_set import UrlSet
 
 
@@ -28,34 +26,33 @@ def is_rate_limit(response) -> bool:
 
 def scrape_instagram(user_id: str, session, url_set: UrlSet) -> None:
     domain = 'www.instagram.com'
-    base = 'https://{domain}'.format(domain=domain)
-    url = '{base}/{user_id}/'.format(base=base, user_id=user_id)
+    # cookie_domain = '.instagram.com'
+    base = f'https://{domain}'
+    user_url = f'{base}/{user_id}/'
+    # url = f'{base}'
+    url = "https://i.instagram.com/api/v1/users/web_profile_info"
 
     logger = logging.getLogger(__name__)
 
-    response = session.get(url)
-    root = pyscrapers.core.utils.get_html_dom_content(response)
-    # scrape.utils.print_element(root)
+    response = session.get(user_url)
+    response.raise_for_status()
+    params = {
+        "username": user_id,
+    }
+    headers = {
+        "x-ig-app-id": "936619743392459",
+    }
+    response = session.get(url, params=params, headers=headers)
+    response.raise_for_status()
+    obj = response.json()
+    user_id_json = obj["data"]["user"]["id"]
+    profile_pic_url_hd = obj["data"]["user"]["profile_pic_url_hd"]
+    url_set.append(profile_pic_url_hd)
+    get_urls(logger, session, base, url_set, user_id_json)
 
-    # register regular expressions with lxml
-    # this means that we can use regular expression functions like 'match'
-    # by specifying 're:match' in our xpath expressions
-    ns = etree.FunctionNamespace("http://exslt.org/regular-expressions")
-    ns.prefix = 're'
-    e_a = root.xpath('//script[re:match(text(), "^window._sharedData")]')
-    assert len(e_a) == 1
-    data = e_a[0].text
-    json_text = data[data.find('{'):data.rfind('}') + 1]
-    d = json.loads(json_text)
-    my_list = d['entry_data']['ProfilePage']
-    assert len(my_list) == 1
-    c = my_list[0]["graphql"]["user"]
-    if 'profile_pic_url_hd' in c:
-        url_set.append(c['profile_pic_url_hd'])
-    elif 'profile_pic_url' in c:
-        url_set.append(c['profile_pic_url'])
-    user_id = c['id']
-    url2 = '{base}/graphql/query/'.format(base=base)
+
+def get_urls(logger, session, base, url_set, user_id):
+    url = f'{base}/graphql/query/'
     count = 50
     query_hashes = [
         'bd0d6d184eefd4d0ce7036c11ae58ed9',  # posts
@@ -69,13 +66,13 @@ def scrape_instagram(user_id: str, session, url_set: UrlSet) -> None:
     stats_image = 0
     stats_shortcode_video = 0
     for query_hash, key in zip(query_hashes, keys):
-        logger.debug("size of list is [{}]".format(len(url_set.urls_list)))
+        logger.info(f"size of list is [{len(url_set.urls_list)}]")
         has_next_page = True
         end_cursor = None
         while has_next_page:
             variables = {
-                    'id': user_id,
-                    'first': count,
+                'id': user_id,
+                'first': count,
             }
             if end_cursor:
                 variables['after'] = end_cursor
@@ -83,7 +80,7 @@ def scrape_instagram(user_id: str, session, url_set: UrlSet) -> None:
                 'query_hash': query_hash,
                 'variables': json.dumps(variables)
             }
-            response = session.get(url2, params=params).json()
+            response = session.get(url, params=params).json()
             data_user = response['data']['user'][key]
             has_next_page = data_user['page_info']['has_next_page']
             end_cursor = data_user['page_info']['end_cursor']
@@ -97,10 +94,11 @@ def scrape_instagram(user_id: str, session, url_set: UrlSet) -> None:
                         'query_hash': '03f541f086ce0a9b31f67688ff9c1e09',
                         'shortcode': inner_node['shortcode'],
                     }
-                    response_short = session.get(url2, params=params).json()
+                    response_short = session.get(url, params=params).json()
                     while is_rate_limit(response_short):
+                        logger.info("ratelimit, sleeping...")
                         time.sleep(60)
-                        response_short = session.get(url2, params=params).json()
+                        response_short = session.get(url, params=params).json()
                     if 'data' in response_short:
                         url_set.append(response_short['data']['shortcode_media']['video_url'])
                     else:
@@ -109,6 +107,6 @@ def scrape_instagram(user_id: str, session, url_set: UrlSet) -> None:
                 if 'display_url' in inner_node:
                     url_set.append(inner_node['display_url'])
                     stats_image += 1
-    logger.info("stats_video [{}]".format(stats_video))
-    logger.info("stats_image [{}]".format(stats_image))
-    logger.info("stats_shortcode_video [{}]".format(stats_shortcode_video))
+    logger.info(f"stats_video [{stats_video}]")
+    logger.info(f"stats_image [{stats_image}]")
+    logger.info(f"stats_shortcode_video [{stats_shortcode_video}]")
